Dutch Form

# Localization with Ext

This demonstrates a dutch location of Ext using the form component. It includes the localization file "ext-lang-nl.js" from the source/locale folder of the Ext download. By placing all language text such as field labels and button labels and date formats in the prototype, we can easily localize our components by overriding these values. View ContactForm.jsand ContactForm-nl.js to learn how Ext applies internationalization to JavaScript.

The js is not minified so it is readable. See ContactForm.js and ContactForm-nl.js.